==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/avfoundation/AVVideoCompositionCoreAnimationTool.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
import org.robovm.apple.audiounit.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 4.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("AVFoundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/AVVideoCompositionCoreAnimationTool/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class AVVideoCompositionCoreAnimationToolPtr extends Ptr<AVVideoCompositionCoreAnimationTool, AVVideoCompositionCoreAnimationToolPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(AVVideoCompositionCoreAnimationTool.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public AVVideoCompositionCoreAnimationTool() {}
    protected AVVideoCompositionCoreAnimationTool(SkipInit skipInit) { super(skipInit); }
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(CALayer layer, int trackID) { super(create(layer, trackID)); retain(getHandle()); }
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(CALayer videoLayer, CALayer animationLayer) { super(create(videoLayer, animationLayer)); retain(getHandle()); }
    /**
     * @since Available in iOS 7.0 and later.
     */
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(NSArray<CALayer> videoLayers, CALayer animationLayer) { super(create(videoLayers, animationLayer)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithAdditionalLayer:asTrackID:")
    protected static native @Pointer long create(CALayer layer, int trackID);
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithPostProcessingAsVideoLayer:inLayer:")
    protected static native @Pointer long create(CALayer videoLayer, CALayer animationLayer);
    /**
     * @since Available in iOS 7.0 and later.
     */
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithPostProcessingAsVideoLayers:inLayer:")
    protected static native @Pointer long create(NSArray<CALayer> videoLayers, CALayer animationLayer);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/avfoundation/AVVideoCompositionCoreAnimationTool.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("AVFoundation") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/AVVideoCompositionCoreAnimationTool/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class AVVideoCompositionCoreAnimationToolPtr extends Ptr<AVVideoCompositionCoreAnimationTool, AVVideoCompositionCoreAnimationToolPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(AVVideoCompositionCoreAnimationTool.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public AVVideoCompositionCoreAnimationTool() {}
    protected AVVideoCompositionCoreAnimationTool(Handle h, long handle) { super(h, handle); }
    protected AVVideoCompositionCoreAnimationTool(SkipInit skipInit) { super(skipInit); }
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(CALayer layer, int trackID) { super((Handle) null, create(layer, trackID)); retain(getHandle()); }
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(CALayer videoLayer, CALayer animationLayer) { super((Handle) null, create(videoLayer, animationLayer)); retain(getHandle()); }
    @WeaklyLinked
    public AVVideoCompositionCoreAnimationTool(NSArray<CALayer> videoLayers, CALayer animationLayer) { super((Handle) null, create(videoLayers, animationLayer)); retain(getHandle()); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithAdditionalLayer:asTrackID:")
    protected static native @Pointer long create(CALayer layer, int trackID);
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithPostProcessingAsVideoLayer:inLayer:")
    protected static native @Pointer long create(CALayer videoLayer, CALayer animationLayer);
    @WeaklyLinked
    @Method(selector = "videoCompositionCoreAnimationToolWithPostProcessingAsVideoLayers:inLayer:")
    protected static native @Pointer long create(NSArray<CALayer> videoLayers, CALayer animationLayer);
    /*</methods>*/
}
